# Bon API

Application programming interface to BON blockchain nodes.  This is for
read-only API calls.  If you need to sign transactions use
[bonjs](https://github.com/betterchainio/bonjs) instead.

# Include

* Install with: `npm install bonjs-api`
* Html script tag, see [releases](https://github.com/betterchainio/bonjs-api/releases) for the correct **version** and its matching script **integrity** hash.

```html
<html>
<head>
  <meta charset="utf-8">
  <!--
  sha512-oiuFmDyPAiD3PIiAYLyie70WmRWBy+Eq1Xar8Siz2HDGAv8B6O9tcjW9lC9isYbS/TOs4OkZAsQBln206Mb9Wg== lib/bon-api.js
  sha512-LLDsX/GdVZYA82k9TVz3zUxSjvaX8s5b1FJm64W51JGxLFKI2z+ljqYQtsUZIOxh9pSUqvLA5HCoxXqdRxusKw== lib/bon-api.min.js
  sha512-UuHPS649Xw5vATdmB0X7z+jgbdfmxiaeraqNtvq9T6bG1k8NX9Az8YrT4GmX5gBpbIX+z3vOomFnBX1RmnDDTA== lib/bon-api.min.js.map
  -->
  <script src="https://cdn.jsdelivr.net/npm/bonjs-api@7.0.3/lib/bon-api.min.js"
    integrity="sha512-LLDsX/GdVZYA82k9TVz3zUxSjvaX8s5b1FJm64W51JGxLFKI2z+ljqYQtsUZIOxh9pSUqvLA5HCoxXqdRxusKw=="
    crossorigin="anonymous"></script>

</head>
<body>
  See console object: BonApi
</body>
</html>
```

## BonApi

Run [nodbon](https://github.com/betterchainio/bon)

## Usage

```javascript
BonApi = require('bonjs-api') // Or BonApi = require('./src')

bon = BonApi() // // 127.0.0.1:8888

// Any API call without a callback parameter will print documentation: description,
// parameters, return value, and possible errors.  All methods and documentation
// are created from JSON files in bonjs/json/api/v1..
bon.getInfo()

// A Promise is returned if a callback is not provided.
bon.getInfo({}).then(result => console.log(result))
bon.getBlock(1).then(result => console.log(result))

// For callbacks instead of Promises provide a callback
callback = (err, res) => {err ? console.error(err) : console.log(res)}

// The server does not expect any parameters only the callback is needed
bon.getInfo(callback)

// Parameters are added before the callback
bon.getBlock(1, callback)

// Parameters can be an object
bon.getBlock({block_num_or_id: 1}, callback)
bon.getBlock({block_num_or_id: 1}).then(result => console.log(result))
```

## Configuration

```js
BonApi = require('bonjs-api') // Or BonApi = require('./src')

// everything is optional
options = {
  httpEndpoint: 'http://127.0.0.1:8888', // default, null for cold-storage
  verbose: false, // API logging
  logger: { // Default logging functions
    log: config.verbose ? console.log : null,
    error: config.verbose ? console.error : null
  },
  fetchConfiguration: {}
}

bon = BonApi(options)
```
### options.logger example

During testing, an error may be expected and checked as follows:

```js
options.logger = {
  error: err => {
    assert.equal(err, 'expected error')
    done()
  }
}
```

### options.fetchConfiguration example

```js
options.fetchConfiguration = {
  credentials: 'same-origin'
}
```
Every bonjs-api request will run [fetch](https://github.com/github/fetch#sending-cookies) with this configuration:
```js
fetch('https://example.com', {
  credentials: 'same-origin'
})
```

## Environment

Node and browser (es2015)
